@@ -53,7 +53,7 @@ log.setLevel(logging.DEBUG)
 
 def handle_term(signum, frame):
     log.warning('Terminated')
-    raise SystemExit(0)
+    raise KeyboardInterrupt()
 
 
 signal.signal(signal.SIGINT, handle_term)
@@ -983,6 +983,10 @@ class NumerousAdminClient(NumerousClient):
             project_id=project, scenario_id=scenario, job_id=job, user_id=self._user, organization_id=self._organization
         ))
 
+    def listen_executions(self):
+        for doc in self._base_client.ListenExecutions():
+            yield json.loads(doc)
+
 
 
 
